==> antragsgruen-3.6.8.tar.bz2: antragsgruen-3.6.8/messages/en/structure.php <==
<?php
return [
    'section_title'   => 'Title',
    'section_text'    => 'Text',
    'section_html'    => 'Text (enhanced)',
    'section_image'   => 'Image',
    'section_tabular' => 'Tabular data',
    'section_pdf'     => 'PDF file',

    'policy_deadline_over'    => 'The deadline is over',
    'policy_ww_title'         => 'Wurzelwerk-Users',
    'policy_ww_desc'          => 'Wurzelwerk-Users',
    'policy_ww_motion_denied' => 'Only Wurzelwerk-users can create motions.',
    'policy_ww_amend_denied'  => 'Only Wurzelwerk-users can create amendments.',
    'policy_ww_comm_denied'   => 'Only Wurzelwerk-users can comment',
    'policy_ww_supp_denied'   => 'Only Wurzelwerk-users can support',

    'policy_admin_title'         => 'Admins',
    'policy_admin_desc'          => 'Admins',
    'policy_admin_motion_denied' => 'Only admins can create motions.',
    'policy_admin_amend_denied'  => 'Only admins can create amendments.',
    'policy_admin_comm_denied'   => 'Only admins can comment',
    'policy_admin_supp_denied'   => 'Only admins can support',

    'policy_all_title'            => 'Everyone',
    'policy_all_desc'             => 'Everyone',
    'policy_nobody_title'         => 'Nobody',
    'policy_nobody_motion_denied' => 'Currently nobody can create motions.',
    'policy_nobody_amend_denied'  => 'Currently nobody can create amendments.',
    'policy_nobody_comm_denied'   => 'Currently nobody can comment.',
    'policy_nobody_supp_denied'   => 'Currently nobody can support.',

    'policy_logged_title'           => 'Registered users',
    'policy_logged_desc'            => 'Registered users',
    'policy_specuser_motion_denied' => 'Only explicitly entitled users can create motions.',
    'policy_specuser_amend_denied'  => 'Only explicitly entitled users can create amendments.',
    'policy_specuser_supp_denied'   => 'Only explicitly entitled users can support.',
    'policy_specuser_comm_denied'   => 'Only explicitly entitled users can comment.',
    'policy_logged_motion_denied'   => 'You need to log in to create motions.',
    'policy_logged_amend_denied'    => 'You need to log in to create amendments.',
    'policy_logged_supp_denied'     => 'You need to log in to support.',
    'policy_logged_comm_denied'     => 'You need to log in to comment.',

    'preset_bdk_name'           => 'German federal convention',
    'preset_bdk_desc'           => 'Presets similar to the federal convention of the German Green Party. This setting does not make sense outside of Germany.',
    'preset_election_name'      => 'Application / elections',
    'preset_election_desc'      => '',
    'preset_motions_name'       => 'Motions',
    'preset_motions_desc'       => 'Everyone can create motions and amendments. They need to be screened by conference administrators, though.',
    'preset_party_name'         => 'Political convention',
    'preset_party_desc'         => 'A convention with a sample agenda. Users can apply for mandates and create motions and amendments. The agenda and mandates can be adjusted deliberately.',
    'preset_party_top'          => 'Agenda',
    'preset_party_elections'    => 'Elections',
    'preset_party_1leader'      => 'Election: 1st chairperson',
    'preset_party_2leader'      => 'Election: 2nd chairperson',
    'preset_party_treasure'     => 'Election: treasurer',
    'preset_party_motions'      => 'Motions',
    'preset_party_misc'         => 'Miscellaneous',
    'preset_manifesto_name'     => 'Election programme', // @TODO
    'preset_manifesto_desc'     => 'A draft version of the programme is published by administrators. Users can comment on the drafts and create amendments. The latter have to be screened before they are published. Everyone can comment.',
    'preset_manifesto_title'    => 'Chapter title',
    'preset_manifesto_text'     => 'Text',
    'preset_manifesto_singular' => 'Chapter',
    'preset_manifesto_plural'   => 'Chapters',
    'preset_manifesto_call'     => 'Create a chapter',

    'preset_app_singular'  => 'Application',
    'preset_app_plural'    => 'Applications',
    'preset_app_call'      => 'Apply',
    'preset_app_name'      => 'Name',
    'preset_app_photo'     => 'Photo',
    'preset_app_data'      => 'Data',
    'preset_app_signature' => 'Signature (scanned)',
    'preset_app_age'       => 'Age',
    'preset_app_gender'    => 'Gender',
    'preset_app_birthcity' => 'Place of birth',
    'preset_app_intro'     => 'Introduction',

    'preset_motion_singular' => 'Motion',
    'preset_motion_plural'   => 'Motions',
    'preset_motion_call'     => 'Start a motion',
    'preset_motion_title'    => 'Title',
    'preset_motion_text'     => 'Motion text',
    'preset_motion_reason'   => 'Reason',

    'role_initiator' => 'Proposer',
    'role_supporter' => 'Supporter',
    'role_likes'     => 'Likes',
    'role_dislikes'  => 'Dislikes',

    'person_type_natural' => 'Natural person',
    'person_type_orga'    => 'Organization',

    'user_status_1'  => 'Unconfirmed',
    'user_status_0'  => 'Confirmed',
    'user_status_-1' => 'Deleted',

    'STATUS_DELETED'                      => 'Deleted',
    'STATUS_WITHDRAWN'                    => 'Withdrawn',
    'STATUS_WITHDRAWN_INVISIBLE'          => 'Withdrawn (invisible)',
    'STATUS_UNCONFIRMED'                  => 'Unconfirmed',
    'STATUS_DRAFT'                        => 'Draft',
    'STATUS_SUBMITTED_UNSCREENED'         => 'Submitted (unscreened)',
    'STATUS_SUBMITTED_SCREENED'           => 'Submitted',
    'STATUS_ACCEPTED'                     => 'Accepted',
    'STATUS_REJECTED'                     => 'Rejected',
    'STATUS_MODIFIED_ACCEPTED'            => 'Accepted (modified)',
    'STATUS_MODIFIED'                     => 'Modified',
    'STATUS_ADOPTED'                      => 'Adopted',
    'STATUS_COMPLETED'                    => 'Completed',
    'STATUS_REFERRED'                     => 'Referred',
    'STATUS_VOTE'                         => 'Vote',
    'STATUS_PAUSED'                       => 'Paused',
    'STATUS_MISSING_INFORMATION'          => 'Missing information',
    'STATUS_DISMISSED'                    => 'Dismissed',
    'STATUS_COLLECTING_SUPPORTERS'        => 'Call for supporters',
    'STATUS_DRAFT_ADMIN'                  => 'Draft (Admin)',
    'STATUS_SUBMITTED_UNSCREENED_CHECKED' => 'Submitted (screened, not yet published)',

    'section_comment_none'      => 'No comments',
    'section_comment_motion'    => 'Comment the whole motion as one',
    'section_comment_paragraph' => 'Comment single paragraphs',

    'home_layout_std'         => 'Standard',
    'home_layout_tags'        => 'Tabular, grouped by tags',
    'home_layout_agenda'      => 'Agenda',
    'home_layout_agenda_long' => 'Agenda (many motions)',

    'supp_only_initiators'    => 'Only proposer',
    'supp_given_by_initiator' => 'Supporters given by proposer',
    'supp_collect_before'     => 'Collecting phase before publication (not for organizations)',

    'activity_none'                       => 'No activity yet',
    'activity_someone'                    => 'Someone',
    'activity_deleted'                    => 'deleted',
    'activity_MOTION_DELETE'              => '###USER### <strong>deleted the motion ###MOTION###</strong>',
    'activity_MOTION_DELETE_PUBLISHED'    => '###USER### <strong>deleted the motion ###MOTION###</strong>',
    'activity_MOTION_PUBLISH'             => '###USER### <strong>submitted the motion</strong>',
    'activity_MOTION_WITHDRAW'            => 'The motion was <strong>withdrawn</strong>.',
    'activity_MOTION_COMMENT'             => '###USER### <strong>commented on the motion</strong>',
    'activity_MOTION_SCREEN'              => 'The <strong>motion was published</strong>',
    'activity_AMENDMENT_PUBLISH'          => '###USER### <strong>submitted the amendment ###AMENDMENT###</strong>',
    'activity_AMENDMENT_CHANGE'           => '###USER### <strong>edited the amendment ###AMENDMENT###</strong>',
    'activity_AMENDMENT_DELETE'           => '###USER### <strong>deleted the amendment ###AMENDMENT###</strong>',
    'activity_AMENDMENT_DELETE_PUBLISHED' => '###USER### <strong>deleted the amendment ###AMENDMENT###</strong>',
    'activity_AMENDMENT_WITHDRAW'         => 'The <strong>amendment ###AMENDMENT###</strong> was <strong>withdrawn</strong>.',
    'activity_AMENDMENT_COMMENT'          => '###USER### <strong>commented on the amendment ###AMENDMENT###</strong>',
    'activity_AMENDMENT_SCREEN'           => 'The <strong>amendment ###AMENDMENT###</strong> was <strong>published</strong>',
];

==> antragsgruen-3.7.3.tar.bz2: antragsgruen-3.7.3/messages/en/structure.php <==
<?php
return [
    'section_title'   => 'Title',
    'section_text'    => 'Text',
    'section_html'    => 'Text (enhanced)',
    'section_image'   => 'Image',
    'section_tabular' => 'Tabular data',
    'section_pdf'     => 'PDF file',

    'amend_number_permotion' => 'Ä1 for A1 (Numbering per motion)',
    'amend_number_global'    => 'Ä1 for A1 (Global numbering)',
    'amend_number_perline'   => 'A01-070 (Numbering per affected line)',

    'policy_deadline_over'    => 'The deadline is over',
    'policy_ww_title'         => 'Wurzelwerk-Users',
    'policy_ww_desc'          => 'Wurzelwerk-Users',
    'policy_ww_motion_denied' => 'Only Wurzelwerk-users can create motions.',
    'policy_ww_amend_denied'  => 'Only Wurzelwerk-users can create amendments.',
    'policy_ww_comm_denied'   => 'Only Wurzelwerk-users can comment',
    'policy_ww_supp_denied'   => 'Only Wurzelwerk-users can support',

    'policy_admin_title'         => 'Admins',
    'policy_admin_desc'          => 'Admins',
    'policy_admin_motion_denied' => 'Only admins can create motions.',
    'policy_admin_amend_denied'  => 'Only admins can create amendments.',
    'policy_admin_comm_denied'   => 'Only admins can comment',
    'policy_admin_supp_denied'   => 'Only admins can support',

    'policy_all_title'            => 'Everyone',
    'policy_all_desc'             => 'Everyone',
    'policy_nobody_title'         => 'Nobody',
    'policy_nobody_motion_denied' => 'Currently nobody can create motions.',
    'policy_nobody_amend_denied'  => 'Currently nobody can create amendments.',
    'policy_nobody_comm_denied'   => 'Currently nobody can comment.',
    'policy_nobody_supp_denied'   => 'Currently nobody can support.',

    'policy_logged_title'           => 'Registered users',
    'policy_logged_desc'            => 'Registered users',
    'policy_specuser_motion_denied' => 'Only explicitly entitled users can create motions.',
    'policy_specuser_amend_denied'  => 'Only explicitly entitled users can create amendments.',
    'policy_specuser_supp_denied'   => 'Only explicitly entitled users can support.',
    'policy_specuser_comm_denied'   => 'Only explicitly entitled users can comment.',
    'policy_logged_motion_denied'   => 'You need to log in to create motions.',
    'policy_logged_amend_denied'    => 'You need to log in to create amendments.',
    'policy_logged_supp_denied'     => 'You need to log in to support.',
    'policy_logged_comm_denied'     => 'You need to log in to comment.',

    'preset_bdk_name'           => 'German federal convention',
    'preset_bdk_desc'           => 'Presets similar to the federal convention of the German Green Party. This setting does not make sense outside of Germany.',
    'preset_election_name'      => 'Application / elections',
    'preset_election_desc'      => '',
    'preset_motions_name'       => 'Motions',
    'preset_motions_desc'       => 'Everyone can create motions and amendments. They need to be screened by conference administrators, though.',
    'preset_party_name'         => 'Political convention',
    'preset_party_desc'         => 'A convention with a sample agenda. Users can apply for mandates and create motions and amendments. The agenda and mandates can be adjusted deliberately.',
    'preset_party_top'          => 'Agenda',
    'preset_party_elections'    => 'Elections',
    'preset_party_1leader'      => 'Election: 1st chairperson',
    'preset_party_2leader'      => 'Election: 2nd chairperson',
    'preset_party_treasure'     => 'Election: treasurer',
    'preset_party_motions'      => 'Motions',
    'preset_party_misc'         => 'Miscellaneous',
    'preset_manifesto_name'     => 'Election programme', // @TODO
    'preset_manifesto_desc'     => 'A draft version of the programme is published by administrators. Users can comment on the drafts and create amendments. The latter have to be screened before they are published. Everyone can comment.',
    'preset_manifesto_title'    => 'Chapter title',
    'preset_manifesto_text'     => 'Text',
    'preset_manifesto_singular' => 'Chapter',
    'preset_manifesto_plural'   => 'Chapters',
    'preset_manifesto_call'     => 'Create a chapter',

    'preset_app_singular'  => 'Application',
    'preset_app_plural'    => 'Applications',
    'preset_app_call'      => 'Apply',
    'preset_app_name'      => 'Name',
    'preset_app_photo'     => 'Photo',
    'preset_app_data'      => 'Data',
    'preset_app_signature' => 'Signature (scanned)',
    'preset_app_age'       => 'Age',
    'preset_app_gender'    => 'Gender',
    'preset_app_birthcity' => 'Place of birth',
    'preset_app_intro'     => 'Introduction',

    'preset_motion_singular' => 'Motion',
    'preset_motion_plural'   => 'Motions',
    'preset_motion_call'     => 'Start a motion',
    'preset_motion_title'    => 'Title',
    'preset_motion_text'     => 'Motion text',
    'preset_motion_reason'   => 'Reason',

    'role_initiator' => 'Proposer',
    'role_supporter' => 'Supporter',
    'role_likes'     => 'Likes',
    'role_dislikes'  => 'Dislikes',

    'person_type_natural' => 'Natural person',
    'person_type_orga'    => 'Organization',

    'user_status_1'  => 'Unconfirmed',
    'user_status_0'  => 'Confirmed',
    'user_status_-1' => 'Deleted',

    'STATUS_DELETED'                      => 'Deleted',
    'STATUS_WITHDRAWN'                    => 'Withdrawn',
    'STATUS_WITHDRAWN_INVISIBLE'          => 'Withdrawn (invisible)',
    'STATUS_UNCONFIRMED'                  => 'Unconfirmed',
    'STATUS_DRAFT'                        => 'Draft',
    'STATUS_SUBMITTED_UNSCREENED'         => 'Submitted (unscreened)',
    'STATUS_SUBMITTED_SCREENED'           => 'Submitted',
    'STATUS_ACCEPTED'                     => 'Accepted',
    'STATUS_REJECTED'                     => 'Rejected',
    'STATUS_MODIFIED_ACCEPTED'            => 'Accepted (modified)',
    'STATUS_MODIFIED'                     => 'Modified',
    'STATUS_ADOPTED'                      => 'Adopted',
    'STATUS_COMPLETED'                    => 'Completed',
    'STATUS_REFERRED'                     => 'Referred',
    'STATUS_VOTE'                         => 'Vote',
    'STATUS_PAUSED'                       => 'Paused',
    'STATUS_MISSING_INFORMATION'          => 'Missing information',
    'STATUS_DISMISSED'                    => 'Dismissed',
    'STATUS_COLLECTING_SUPPORTERS'        => 'Call for supporters',
    'STATUS_DRAFT_ADMIN'                  => 'Draft (Admin)',
    'STATUS_PROCESSED'                    => 'Processed',
    'STATUS_SUBMITTED_UNSCREENED_CHECKED' => 'Submitted (screened, not yet published)',

    'section_comment_none'      => 'No comments',
    'section_comment_motion'    => 'Comment the whole motion as one',
    'section_comment_paragraph' => 'Comment single paragraphs',

    'home_layout_std'         => 'Standard',
    'home_layout_tags'        => 'Tags',
    'home_layout_agenda'      => 'Agenda',
    'home_layout_agenda_long' => 'Agenda (many motions)',

    'supp_only_initiators'    => 'Only proposer',
    'supp_given_by_initiator' => 'Supporters given by proposer',
    'supp_collect_before'     => 'Collecting phase before publication (not for organizations)',

    'activity_none'                       => 'No activity yet',
    'activity_someone'                    => 'Someone',
    'activity_deleted'                    => 'deleted',
    'activity_MOTION_DELETE'              => '###USER### <strong>deleted the motion ###MOTION###</strong>',
    'activity_MOTION_DELETE_PUBLISHED'    => '###USER### <strong>deleted the motion ###MOTION###</strong>',
    'activity_MOTION_PUBLISH'             => '###USER### <strong>submitted the motion</strong>',
    'activity_MOTION_WITHDRAW'            => 'The motion was <strong>withdrawn</strong>.',
    'activity_MOTION_COMMENT'             => '###USER### <strong>commented on the motion</strong>',
    'activity_MOTION_SCREEN'              => 'The <strong>motion was published</strong>',
    'activity_AMENDMENT_PUBLISH'          => '###USER### <strong>submitted the amendment ###AMENDMENT###</strong>',
    'activity_AMENDMENT_CHANGE'           => '###USER### <strong>edited the amendment ###AMENDMENT###</strong>',
    'activity_AMENDMENT_DELETE'           => '###USER### <strong>deleted the amendment ###AMENDMENT###</strong>',
    'activity_AMENDMENT_DELETE_PUBLISHED' => '###USER### <strong>deleted the amendment ###AMENDMENT###</strong>',
    'activity_AMENDMENT_WITHDRAW'         => 'The <strong>amendment ###AMENDMENT###</strong> was <strong>withdrawn</strong>.',
    'activity_AMENDMENT_COMMENT'          => '###USER### <strong>commented on the amendment ###AMENDMENT###</strong>',
    'activity_AMENDMENT_SCREEN'           => 'The <strong>amendment ###AMENDMENT###</strong> was <strong>published</strong>',
];
